==> zio-aws-opensearch_2.12-5.17.295.20-sources.jar: zio/aws/opensearch/model/InstanceCountLimits.scala <==
package zio.aws.opensearch.model
import zio.aws.opensearch.model.primitives.{
  MaximumInstanceCount,
  MinimumInstanceCount
}
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import java.lang.Integer
import scala.jdk.CollectionConverters._
final case class InstanceCountLimits(
    minimumInstanceCount: Optional[MinimumInstanceCount] = Optional.Absent,
    maximumInstanceCount: Optional[MaximumInstanceCount] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.opensearch.model.InstanceCountLimits = {
    import InstanceCountLimits.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.opensearch.model.InstanceCountLimits
      .builder()
      .optionallyWith(
        minimumInstanceCount.map(value =>
          MinimumInstanceCount.unwrap(value): Integer
        )
      )(_.minimumInstanceCount)
      .optionallyWith(
        maximumInstanceCount.map(value =>
          MaximumInstanceCount.unwrap(value): Integer
        )
      )(_.maximumInstanceCount)
      .build()
  }
  def asReadOnly: zio.aws.opensearch.model.InstanceCountLimits.ReadOnly =
    zio.aws.opensearch.model.InstanceCountLimits.wrap(buildAwsValue())
}
object InstanceCountLimits {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.opensearch.model.InstanceCountLimits
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.opensearch.model.InstanceCountLimits =
      zio.aws.opensearch.model.InstanceCountLimits(
        minimumInstanceCount.map(value => value),
        maximumInstanceCount.map(value => value)
      )
    def minimumInstanceCount: Optional[MinimumInstanceCount]
    def maximumInstanceCount: Optional[MaximumInstanceCount]
    def getMinimumInstanceCount: ZIO[Any, AwsError, MinimumInstanceCount] =
      AwsError.unwrapOptionField("minimumInstanceCount", minimumInstanceCount)
    def getMaximumInstanceCount: ZIO[Any, AwsError, MaximumInstanceCount] =
      AwsError.unwrapOptionField("maximumInstanceCount", maximumInstanceCount)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.opensearch.model.InstanceCountLimits
  ) extends zio.aws.opensearch.model.InstanceCountLimits.ReadOnly {
    override val minimumInstanceCount: Optional[MinimumInstanceCount] =
      zio.aws.core.internal
        .optionalFromNullable(impl.minimumInstanceCount())
        .map(value =>
          zio.aws.opensearch.model.primitives.MinimumInstanceCount(value)
        )
    override val maximumInstanceCount: Optional[MaximumInstanceCount] =
      zio.aws.core.internal
        .optionalFromNullable(impl.maximumInstanceCount())
        .map(value =>
          zio.aws.opensearch.model.primitives.MaximumInstanceCount(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.opensearch.model.InstanceCountLimits
  ): zio.aws.opensearch.model.InstanceCountLimits.ReadOnly = new Wrapper(impl)
}

==> zio-aws-opensearch_3-5.17.202.1-sources.jar: zio/aws/opensearch/model/InstanceCountLimits.scala <==
package zio.aws.opensearch.model
import zio.aws.opensearch.model.primitives.{
  MaximumInstanceCount,
  MinimumInstanceCount
}
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import java.lang.Integer
import scala.jdk.CollectionConverters.*
final case class InstanceCountLimits(
    minimumInstanceCount: Optional[MinimumInstanceCount] = Optional.Absent,
    maximumInstanceCount: Optional[MaximumInstanceCount] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.opensearch.model.InstanceCountLimits = {
    import InstanceCountLimits.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.opensearch.model.InstanceCountLimits
      .builder()
      .optionallyWith(
        minimumInstanceCount.map(value =>
          MinimumInstanceCount.unwrap(value): Integer
        )
      )(_.minimumInstanceCount)
      .optionallyWith(
        maximumInstanceCount.map(value =>
          MaximumInstanceCount.unwrap(value): Integer
        )
      )(_.maximumInstanceCount)
      .build()
  }
  def asReadOnly: zio.aws.opensearch.model.InstanceCountLimits.ReadOnly =
    zio.aws.opensearch.model.InstanceCountLimits.wrap(buildAwsValue())
}
object InstanceCountLimits {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.opensearch.model.InstanceCountLimits
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.opensearch.model.InstanceCountLimits =
      zio.aws.opensearch.model.InstanceCountLimits(
        minimumInstanceCount.map(value => value),
        maximumInstanceCount.map(value => value)
      )
    def minimumInstanceCount: Optional[MinimumInstanceCount]
    def maximumInstanceCount: Optional[MaximumInstanceCount]
    def getMinimumInstanceCount: ZIO[Any, AwsError, MinimumInstanceCount] =
      AwsError.unwrapOptionField("minimumInstanceCount", minimumInstanceCount)
    def getMaximumInstanceCount: ZIO[Any, AwsError, MaximumInstanceCount] =
      AwsError.unwrapOptionField("maximumInstanceCount", maximumInstanceCount)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.opensearch.model.InstanceCountLimits
  ) extends zio.aws.opensearch.model.InstanceCountLimits.ReadOnly {
    override val minimumInstanceCount: Optional[MinimumInstanceCount] =
      zio.aws.core.internal
        .optionalFromNullable(impl.minimumInstanceCount())
        .map(value =>
          zio.aws.opensearch.model.primitives.MinimumInstanceCount(value)
        )
    override val maximumInstanceCount: Optional[MaximumInstanceCount] =
      zio.aws.core.internal
        .optionalFromNullable(impl.maximumInstanceCount())
        .map(value =>
          zio.aws.opensearch.model.primitives.MaximumInstanceCount(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.opensearch.model.InstanceCountLimits
  ): zio.aws.opensearch.model.InstanceCountLimits.ReadOnly = new Wrapper(impl)
}
